package com.djhk.uav.equ.mapper;



import com.djhk.uav.equ.domain.Metasploitable;

import java.util.List;

/**
 * 靶机型号Mapper接口
 *
 * @author huangqg
 * @date 2023-06-01
 */
public interface MetasploitableMapper
{
    /**
     * 查询靶机型号
     *
     * @param id 靶机型号主键
     * @return 靶机型号
     */
    public Metasploitable selectMetasploitableById(Long id);

    /**
     * 查询靶机型号列表
     *
     * @param metasploitable 靶机型号
     * @return 靶机型号集合
     */
    public List<Metasploitable> selectMetasploitableList(Metasploitable metasploitable);

    /**
     * 新增靶机型号
     *
     * @param metasploitable 靶机型号
     * @return 结果
     */
    public int insertMetasploitable(Metasploitable metasploitable);

    /**
     * 批量导入新增靶机型号
     *
     * @param metasploitable 靶机型号
     * @return 结果
     */
    public int insertMetasploitables(Metasploitable metasploitable);

    List<Metasploitable> checkModelCode(String modelCode);

    /**
     * 修改靶机型号
     *
     * @param metasploitabl 靶机型号
     * @return 结果
     */
    public int updateMetasploitable(Metasploitable metasploitabl);

    /**
     * 删除靶机型号
     *
     * @param ids 靶机型号主键
     * @return 结果
     */
    int deleteMetasploitableByIds(Long[] ids);

    List<Metasploitable> selectEquInfoExportList(Metasploitable metasploitable);
//
//    /**
//     * 批量删除靶机型号
//     *
//     * @param modelIds 需要删除的数据主键集合
//     * @return 结果
//     */
//    public int deleteMetasploitableByModelIds(Long[] modelIds);


    public List<Metasploitable> selectMetasploitableType();
}
